# cftscal: tools for calibrating equipment used by CFTS

**cftscal** is a Python package that provides a simple user interface for
calibrating equipment used by CFTS (e.g., calibration microphones, free-field
speakers, starships and amplifiers).
